aboutsummaryrefslogtreecommitdiff
path: root/src/qt/paymentserver.h
diff options
context:
space:
mode:
authorPhilip Kaufmann <phil.kaufmann@t-online.de>2013-10-18 11:44:05 +0200
committerPhilip Kaufmann <phil.kaufmann@t-online.de>2013-10-19 16:27:04 +0200
commit95d4a2be95a4b902c4cda4a8b57c7be9e572aee6 (patch)
treeddaf3a789207eaade1f03ac79b4989c4b1a40c9c /src/qt/paymentserver.h
parente11107f234b2172a03a7bb5fc5fd28ce00ad4e11 (diff)
downloadbitcoin-95d4a2be95a4b902c4cda4a8b57c7be9e572aee6.tar.xz
paymentserver: style fixes / cleanup
- rename reportError() into message() to be in line with our default message() signal/slot naming (and can be used for all types of messages) - rename some QStrings to not collide with message() function - add a missing message for malformed URIs that IS also used in BitcoinGUI - fix / extend some comments and misc style fixes
Diffstat (limited to 'src/qt/paymentserver.h')
-rw-r--r--src/qt/paymentserver.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/qt/paymentserver.h b/src/qt/paymentserver.h
index f9d827204b..042c41ef64 100644
--- a/src/qt/paymentserver.h
+++ b/src/qt/paymentserver.h
@@ -90,8 +90,8 @@ signals:
// Fired when a valid PaymentACK is received
void receivedPaymentACK(QString);
- // Fired when an error should be reported to the user
- void reportError(QString, QString, unsigned int);
+ // Fired when a message should be reported to the user
+ void message(const QString &title, const QString &message, unsigned int style);
public slots:
// Signal this when the main window's UI is ready